'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.collapsePanel = exports.COLLAPSE_PANEL = exports.setFieldValue = exports.moveFieldValue = exports.deleteFieldValue = exports.addFieldInstance = exports.SET_FIELD_VALUE = exports.MOVE_FIELD_VALUE = exports.DELETE_FIELD_VALUE = exports.ADD_FIELD_INSTANCE = exports.saveRecord = exports.RECORD_SAVE_REJECTED = exports.RECORD_SAVE_FULFILLED = exports.RECORD_SAVE_STARTED = exports.readRecord = exports.RECORD_READ_REJECTED = exports.RECORD_READ_FULFILLED = exports.RECORD_READ_STARTED = exports.createNewRecord = exports.CREATE_NEW_RECORD = exports.logout = exports.LOGOUT_REJECTED = exports.LOGOUT_FULFILLED = exports.LOGOUT_STARTED = exports.login = exports.LOGIN_REJECTED = exports.LOGIN_FULFILLED = exports.LOGIN_STARTED = exports.resetLogin = exports.RESET_LOGIN = exports.redirectLogin = exports.LOGIN_REDIRECTED = exports.configureCSpace = exports.CSPACE_CONFIGURED = undefined;

var _cspaceClient = require('cspace-client');

var _cspaceClient2 = _interopRequireDefault(_cspaceClient);

var _reducers = require('../reducers');

var _recordDataHelpers = require('../helpers/recordDataHelpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var cspace = void 0; /* global window */

var session = void 0;

var CSPACE_CONFIGURED = exports.CSPACE_CONFIGURED = 'CSPACE_CONFIGURED';

var configureCSpace = exports.configureCSpace = function configureCSpace(config) {
  cspace = (0, _cspaceClient2.default)(config);
  session = cspace.session();

  return {
    type: CSPACE_CONFIGURED,
    payload: session.config()
  };
};

var LOGIN_REDIRECTED = exports.LOGIN_REDIRECTED = 'LOGIN_REDIRECTED';

var redirectLogin = exports.redirectLogin = function redirectLogin(replace, attemptedUrl) {
  return function (dispatch) {
    replace('/login');

    dispatch({
      type: LOGIN_REDIRECTED,
      meta: {
        attemptedUrl: attemptedUrl
      }
    });
  };
};

var RESET_LOGIN = exports.RESET_LOGIN = 'RESET_LOGIN';

var resetLogin = exports.resetLogin = function resetLogin() {
  return function (dispatch) {
    return dispatch({
      type: RESET_LOGIN
    });
  };
};

var LOGIN_STARTED = exports.LOGIN_STARTED = 'LOGIN_STARTED';
var LOGIN_FULFILLED = exports.LOGIN_FULFILLED = 'LOGIN_FULFILLED';
var LOGIN_REJECTED = exports.LOGIN_REJECTED = 'LOGIN_REJECTED';

var login = exports.login = function login(username, password) {
  return function (dispatch) {
    dispatch({
      type: LOGIN_STARTED,
      meta: {
        username: username
      }
    });

    session = cspace.session({
      username: username,
      password: password
    });

    session.login().then(function (response) {
      return dispatch({
        type: LOGIN_FULFILLED,
        payload: response,
        meta: {
          username: username
        }
      });
    }).catch(function (error) {
      return dispatch({
        type: LOGIN_REJECTED,
        payload: error,
        meta: {
          username: username
        }
      });
    });
  };
};

var LOGOUT_STARTED = exports.LOGOUT_STARTED = 'LOGOUT_STARTED';
var LOGOUT_FULFILLED = exports.LOGOUT_FULFILLED = 'LOGOUT_FULFILLED';
var LOGOUT_REJECTED = exports.LOGOUT_REJECTED = 'LOGOUT_REJECTED';

var logout = exports.logout = function logout() {
  return function (dispatch) {
    dispatch({
      type: LOGOUT_STARTED
    });

    session.logout().then(function (response) {
      return dispatch({
        type: LOGOUT_FULFILLED,
        payload: response
      });
    }).catch(function (error) {
      return dispatch({
        type: LOGOUT_REJECTED,
        payload: error
      });
    });
  };
};

var CREATE_NEW_RECORD = exports.CREATE_NEW_RECORD = 'CREATE_NEW_RECORD';

var createNewRecord = exports.createNewRecord = function createNewRecord(serviceConfig) {
  return function (dispatch) {
    // TODO: Accept csid to clone.

    // Force this to be async, to be consistent with reading an existing record.

    window.setTimeout(function () {
      dispatch({
        type: CREATE_NEW_RECORD,
        meta: {
          serviceConfig: serviceConfig
        }
      });
    }, 0);
  };
};

var RECORD_READ_STARTED = exports.RECORD_READ_STARTED = 'RECORD_READ_STARTED';
var RECORD_READ_FULFILLED = exports.RECORD_READ_FULFILLED = 'RECORD_READ_FULFILLED';
var RECORD_READ_REJECTED = exports.RECORD_READ_REJECTED = 'RECORD_READ_REJECTED';

var readRecord = exports.readRecord = function readRecord(serviceConfig, csid) {
  return function (dispatch) {
    dispatch({
      type: RECORD_READ_STARTED,
      meta: {
        serviceConfig: serviceConfig,
        csid: csid
      }
    });

    var serviceName = serviceConfig.name;

    session.read(serviceName + '/' + csid).then(function (response) {
      return dispatch({
        type: RECORD_READ_FULFILLED,
        payload: response,
        meta: {
          serviceConfig: serviceConfig,
          csid: csid
        }
      });
    }).catch(function (error) {
      return dispatch({
        type: RECORD_READ_REJECTED,
        payload: error,
        meta: {
          serviceConfig: serviceConfig,
          csid: csid
        }
      });
    });
  };
};

var RECORD_SAVE_STARTED = exports.RECORD_SAVE_STARTED = 'RECORD_SAVE_STARTED';
var RECORD_SAVE_FULFILLED = exports.RECORD_SAVE_FULFILLED = 'RECORD_SAVE_FULFILLED';
var RECORD_SAVE_REJECTED = exports.RECORD_SAVE_REJECTED = 'RECORD_SAVE_REJECTED';

var saveRecord = exports.saveRecord = function saveRecord(recordType, serviceConfig, csid, replace) {
  return function (dispatch, getState) {
    dispatch({
      type: RECORD_SAVE_STARTED,
      meta: {
        serviceConfig: serviceConfig,
        csid: csid
      }
    });

    var serviceName = serviceConfig.name;
    var data = (0, _reducers.getRecordData)(getState(), csid);

    var config = {
      data: (0, _recordDataHelpers.prepareForSending)(data).toJS()
    };

    var save = csid ? session.update(serviceName + '/' + csid, config) : session.create(serviceName, config);

    save.then(function (response) {
      dispatch({
        type: RECORD_SAVE_FULFILLED,
        payload: response,
        meta: {
          serviceConfig: serviceConfig,
          csid: csid
        }
      });

      if (response.status === 201 && response.headers.location) {
        // Redirect to the new record.

        var location = response.headers.location;
        var newRecordCsid = location.substring(location.lastIndexOf('/') + 1);

        replace('/record/' + recordType + '/' + newRecordCsid);
      }
    }).catch(function (error) {
      return dispatch({
        type: RECORD_SAVE_REJECTED,
        payload: error,
        meta: {
          serviceConfig: serviceConfig,
          csid: csid
        }
      });
    });
  };
};

var ADD_FIELD_INSTANCE = exports.ADD_FIELD_INSTANCE = 'ADD_FIELD_INSTANCE';
var DELETE_FIELD_VALUE = exports.DELETE_FIELD_VALUE = 'DELETE_FIELD_VALUE';
var MOVE_FIELD_VALUE = exports.MOVE_FIELD_VALUE = 'MOVE_FIELD_VALUE';
var SET_FIELD_VALUE = exports.SET_FIELD_VALUE = 'SET_FIELD_VALUE';

var addFieldInstance = exports.addFieldInstance = function addFieldInstance(csid, path) {
  return function (dispatch) {
    dispatch({
      type: ADD_FIELD_INSTANCE,
      meta: {
        csid: csid,
        path: path
      }
    });
  };
};

var deleteFieldValue = exports.deleteFieldValue = function deleteFieldValue(csid, path) {
  return function (dispatch) {
    dispatch({
      type: DELETE_FIELD_VALUE,
      meta: {
        csid: csid,
        path: path
      }
    });
  };
};

var moveFieldValue = exports.moveFieldValue = function moveFieldValue(csid, path, newPosition) {
  return function (dispatch) {
    dispatch({
      type: MOVE_FIELD_VALUE,
      meta: {
        csid: csid,
        path: path,
        newPosition: newPosition
      }
    });
  };
};

var setFieldValue = exports.setFieldValue = function setFieldValue(csid, path, value) {
  return function (dispatch) {
    dispatch({
      type: SET_FIELD_VALUE,
      payload: value,
      meta: {
        csid: csid,
        path: path
      }
    });
  };
};

var COLLAPSE_PANEL = exports.COLLAPSE_PANEL = 'COLLAPSE_PANEL';

var collapsePanel = exports.collapsePanel = function collapsePanel(recordType, name, collapsed) {
  return function (dispatch) {
    // TODO: Store in user profile/local storage.

    dispatch({
      type: COLLAPSE_PANEL,
      payload: collapsed,
      meta: {
        recordType: recordType,
        name: name
      }
    });
  };
};