'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.init = init;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactDom = require('react-dom');

var _redux = require('redux');

var _reduxThunk = require('redux-thunk');

var _reduxThunk2 = _interopRequireDefault(_reduxThunk);

var _reactRouter = require('react-router');

var _history = require('history');

var _reactRouterRedux = require('react-router-redux');

var _scriptjs = require('scriptjs');

var _scriptjs2 = _interopRequireDefault(_scriptjs);

var _warning = require('warning');

var _warning2 = _interopRequireDefault(_warning);

var _actions = require('./actions');

var _reducers = require('./reducers');

var _reducers2 = _interopRequireDefault(_reducers);

var _App = require('./components/App');

var _App2 = _interopRequireDefault(_App);

var _object = require('./plugins/record/object');

var _object2 = _interopRequireDefault(_object);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function loadPolyfills(locale, callback) {
  if (window.Intl) {
    window.setTimeout(callback, 0);
  } else {
    var url = 'https://cdn.polyfill.io/v2/polyfill.min.js?features=Intl.~locale.' + locale;

    (0, _scriptjs2.default)(url, callback);
  }
} /* global document, window */

var defaultRecordTypePlugins = {
  object: _object2.default
};

var defaultConfig = {
  basename: '',
  container: 'main',
  cspaceUrl: '',
  index: undefined,
  locale: 'en',
  messages: undefined,
  prettyUrls: false,
  recordTypePlugins: defaultRecordTypePlugins
};

function init(uiConfig) {
  var config = Object.assign({}, defaultConfig, uiConfig);

  var basename = config.basename;
  var container = config.container;
  var cspaceUrl = config.cspaceUrl;
  var index = config.index;
  var locale = config.locale;
  var messages = config.messages;
  var prettyUrls = config.prettyUrls;
  var recordTypePlugins = config.recordTypePlugins;


  var mountNode = document.querySelector(container);

  process.env.NODE_ENV !== 'production' ? (0, _warning2.default)(mountNode, 'No container element was found using the selector \'' + container + '\'. ' + 'The CollectionSpace UI will not be rendered.') : void 0;

  if (mountNode) {
    (function () {
      process.env.NODE_ENV !== 'production' ? (0, _warning2.default)(mountNode !== document.body, 'The container element for the CollectionSpace UI found using the selector \'' + container + '\' ' + 'is the document body. This may cause problems, and is not supported.') : void 0;

      var store = (0, _redux.createStore)(_reducers2.default, (0, _redux.applyMiddleware)(_reduxThunk2.default));

      var baseHistory = prettyUrls ? (0, _reactRouter.useRouterHistory)(_history.createHistory)({ basename: basename }) : _reactRouter.hashHistory;
      var history = (0, _reactRouterRedux.syncHistoryWithStore)(baseHistory, store);

      store.dispatch((0, _actions.configureCSpace)({
        url: cspaceUrl
      }));

      var props = {
        history: history,
        index: index,
        locale: locale,
        messages: messages,
        recordTypePlugins: recordTypePlugins,
        store: store
      };

      loadPolyfills(locale, function () {
        (0, _reactDom.render)(_react2.default.createElement(_App2.default, props), mountNode);
      });
    })();
  }
}

exports.default = {
  init: init
};